// SPDX-License-Identifier: GPL-3.0
pragma solidity ^0.6.0;

import "@openzeppelin/contracts/access/AccessControl.sol";
import "./openzeppelin-contracts/ERC777.sol";
import "./ERC777/ERC777Snapshot.sol";

contract HoprToken is AccessControl, ERC777Snapshot {
    bytes32 public constant MINTER_ROLE = keccak256("MINTER_ROLE");

    constructor() public ERC777("HOPR Token", "HOPR", new address[](0)) {
        _setupRole(DEFAULT_ADMIN_ROLE, msg.sender);
    }

    /**
     * @dev Creates `amount` new tokens for `to`.
     *
     * See {ERC20-_mint}.
     *
     * Requirements:
     *
     * - the caller must have the `MINTER_ROLE`.
     */
    function mint(
        address account,
        uint256 amount,
        bytes memory userData,
        bytes memory operatorData
    ) public {
        require(hasRole(MINTER_ROLE, msg.sender), "HoprToken: caller does not have minter role");
        _mint(account, amount, userData, operatorData);
    }
}
